@@ -5,7 +5,7 @@ support.
 __author__ = 'Gavin M. Roy'
 __email__ = 'gmr@meetme.com'
 __since__ = '2012-04-11'
-__version__ = '1.4.5'
+__version__ = '1.4.6'
 
 import daemon
 import grp
@@ -32,7 +32,7 @@ _CONFIG_KEYS = [_APPLICATION, _DAEMON, _LOGGING]
 _CONFIG_FILE = None
 _CONTROLLER = None
 _DESCRIPTION = 'Command Line Daemon'
-_PIDFILE = '/var/run/%(app)s-%(pid)s.pid'
+_PIDFILE = '/var/run/%(app)s.pid'
 
 logger = logging.getLogger(__name__)
 
@@ -402,7 +402,10 @@ def _get_daemon_context():
         context.gid = _get_gid(config['group'])
 
     # Set the pidfile to write when app has started
-    context.pidfile = lockfile.FileLock(path=_get_pidfile_path())
+    pidfile = _get_pidfile_path()
+    with open(pidfile, "w") as handle:
+        handle.write(str(os.getpid()))
+    context.pidfile = lockfile.FileLock(path=pidfile)
 
     # Setup the signal map
     context.signal_map = {signal.SIGHUP: _on_sighup,
@@ -440,8 +443,7 @@ def _get_pidfile_path():
 
     """
     config = _get_daemon_config()
-    return config.get('pidfile', _PIDFILE) % {'app': _APPNAME,
-                                              'pid': os.getpid()}
+    return config.get('pidfile', _PIDFILE) % {'app': _APPNAME}
 
 
 def _get_uid(username):
